@@ -34,8 +34,8 @@ func (a gradleLockAnalyzer) Analyze(_ context.Context, input analyzer.AnalysisIn
 	return res, nil
 }
 
-func (a gradleLockAnalyzer) Required(_ string, fileInfo os.FileInfo) bool {
-	return strings.HasSuffix(fileInfo.Name(), fileNameSuffix)
+func (a gradleLockAnalyzer) Required(filePath string, _ os.FileInfo) bool {
+	return strings.HasSuffix(filePath, fileNameSuffix)
 }
 
 func (a gradleLockAnalyzer) Type() analyzer.Type {
