@@ -49,10 +49,11 @@ func (a *dpkgLicenseAnalyzer) Analyze(_ context.Context, input analyzer.Analysis
 			return nil, xerrors.Errorf("seek error: %w", err)
 		}
 
-		findings, err = licensing.Classify(input.Content)
+		licenseFile, err := licensing.Classify(input.FilePath, input.Content)
 		if err != nil {
 			return nil, xerrors.Errorf("license classification error: %w", err)
 		}
+		findings = licenseFile.Findings
 	}
 
 	if len(findings) == 0 {
@@ -86,6 +87,8 @@ func (a *dpkgLicenseAnalyzer) parseCopyright(r dio.ReadSeekerAt) ([]types.Licens
 			// Machine-readable format
 			// cf. https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/#:~:text=The%20debian%2Fcopyright%20file%20must,in%20the%20Debian%20Policy%20Manual.
 			l := strings.TrimSpace(line[8:])
+
+			l = normalizeLicense(l)
 			if len(l) > 0 {
 				// Split licenses without considering "and"/"or"
 				// examples:
@@ -135,3 +138,15 @@ func (a *dpkgLicenseAnalyzer) Type() analyzer.Type {
 func (a *dpkgLicenseAnalyzer) Version() int {
 	return dpkgLicenseAnalyzerVersion
 }
+
+// normalizeLicense returns a normalized license identifier in a heuristic way
+func normalizeLicense(s string) string {
+	// "The MIT License (MIT)" => "The MIT License"
+	s, _, _ = strings.Cut(s, "(")
+
+	// Very rarely has below phrases
+	s = strings.TrimPrefix(s, "The main library is licensed under ")
+	s = strings.TrimSuffix(s, " license")
+
+	return strings.TrimSpace(s)
+}
