@@ -35,24 +35,27 @@ func NewSummaryWriter(output io.Writer, requiredSevs []dbTypes.Severity, columnH
 	}
 }
 
-func ColumnHeading(securityChecks, components, availableColumns []string) []string {
-	columns := []string{NamespaceColumn, ResourceColumn}
+func ColumnHeading(scanners types.Scanners, components, availableColumns []string) []string {
+	columns := []string{
+		NamespaceColumn,
+		ResourceColumn,
+	}
 	securityOptions := make(map[string]interface{}, 0)
 	//maintain column order (vuln,config,secret)
-	for _, check := range securityChecks {
+	for _, check := range scanners {
 		switch check {
-		case types.SecurityCheckVulnerability:
+		case types.VulnerabilityScanner:
 			securityOptions[VulnerabilitiesColumn] = nil
-		case types.SecurityCheckConfig:
+		case types.MisconfigScanner:
 			if slices.Contains(components, workloadComponent) {
 				securityOptions[MisconfigurationsColumn] = nil
 			}
 			if slices.Contains(components, infraComponent) {
 				securityOptions[InfraAssessmentColumn] = nil
 			}
-		case types.SecurityCheckSecret:
+		case types.SecretScanner:
 			securityOptions[SecretsColumn] = nil
-		case types.SecurityCheckRbac:
+		case types.RBACScanner:
 			securityOptions[RbacAssessmentColumn] = nil
 		}
 	}
@@ -94,7 +97,10 @@ func (s SummaryWriter) Write(report Report) error {
 		}
 		vCount, mCount, sCount := accumulateSeverityCounts(finding)
 		name := fmt.Sprintf("%s/%s", finding.Kind, finding.Name)
-		rowParts := []string{finding.Namespace, name}
+		rowParts := []string{
+			finding.Namespace,
+			name,
+		}
 
 		if slices.Contains(s.ColumnsHeading, VulnerabilitiesColumn) {
 			rowParts = append(rowParts, s.generateSummary(vCount)...)
@@ -140,9 +146,13 @@ func (s SummaryWriter) generateSummary(sevCount map[string]int) []string {
 }
 
 func getRequiredSeverities(requiredSevs []dbTypes.Severity) ([]string, []string) {
-	requiredSevOrder := []dbTypes.Severity{dbTypes.SeverityCritical,
-		dbTypes.SeverityHigh, dbTypes.SeverityMedium,
-		dbTypes.SeverityLow, dbTypes.SeverityUnknown}
+	requiredSevOrder := []dbTypes.Severity{
+		dbTypes.SeverityCritical,
+		dbTypes.SeverityHigh,
+		dbTypes.SeverityMedium,
+		dbTypes.SeverityLow,
+		dbTypes.SeverityUnknown,
+	}
 	var severities []string
 	var severityHeadings []string
 	for _, sev := range requiredSevOrder {
@@ -178,11 +188,20 @@ func accumulateSeverityCounts(finding Resource) (map[string]int, map[string]int,
 func configureHeader(s SummaryWriter, t *table.Table, columnHeading []string) {
 	sevCount := len(s.Severities)
 	if len(columnHeading) > 2 {
-		headerRow := []string{columnHeading[0], columnHeading[1]}
+		headerRow := []string{
+			columnHeading[0],
+			columnHeading[1],
+		}
 		//  vulnerabilities headings
 		count := len(columnHeading) - len(headerRow)
-		colSpan := []int{1, 1}
-		headerAlignment := []table.Alignment{table.AlignLeft, table.AlignLeft}
+		colSpan := []int{
+			1,
+			1,
+		}
+		headerAlignment := []table.Alignment{
+			table.AlignLeft,
+			table.AlignLeft,
+		}
 		for i := 0; i < count; i++ {
 			headerRow = append(headerRow, s.SeverityHeadings...)
 			colSpan = append(colSpan, sevCount)
