@@ -7,7 +7,8 @@ import (
 // ScanOptions holds the attributes for scanning vulnerabilities
 type ScanOptions struct {
 	VulnType            []string
-	SecurityChecks      []string
+	Scanners            Scanners
+	ImageConfigScanners Scanners // Scanners for container image configuration
 	ScanRemovedPackages bool
 	Platform            string
 	ListAllPackages     bool
